@@ -9,7 +9,11 @@ c        this is used for a table with LPM
       real*8 ale
 
       if(Eg .lt. media.cnst.PrEg1H) then
-         call cerrorMsg('Eg is too low for epPrHSamp',0)
+         write(0,*) ' Eg=',Eg,'<media.cnst.PrEg1H=',media.cnst.PrEg1H
+         call cerrorMsg('Eg is too low for epPrHSamp',1)
+         call epfordebug('in epPrHSamp')
+         stop 1111
+
       elseif(Eg .lt. media.cnst.PrEg2H) then
          ale=log10(Eg)
          call kintp3(media.tbl.PrTXH,
