@@ -40,8 +40,9 @@ c         issue messages.
             icon = 2
             return !  *******
          endif
+         call cerrorMsg(' ',  1)
          call cerrorMsg(
-     *    'If this message comes out at the very beginning of', 1)
+     *    'If following message comes out at the very beginning of', 1)
          call cerrorMsg(
      *    ' an event, better to suspect that your incident particle',1)
          call cerrorMsg(
@@ -57,7 +58,7 @@ c         issue messages.
          call cerrorMsg(
      *    'so check the coordinate below, if they are very ',1)
          call cerrorMsg(
-     *    'near to the boundary ', 1)
+     *    'near to the boundary, it may be ok', 1)
          write(msg, *) ' Cn for current pos=',Cn,
      *           ' which should be ', cnxx
          call cerrorMsg(msg, 1)
@@ -72,7 +73,7 @@ c         issue messages.
          call cerrorMsg(msg, 1)
          write(msg,*) ' cTrack E=',cTrack.p.fm.p(4), ' Move E=',
      *        Move.Track.p.fm.p(4),  ' code=',cTrack.p.code,
-     *        ' chg=',cTrack.p.charge
+     *      ' subcode=', cTrack.p.subcode,' chg=',cTrack.p.charge
          call cerrorMsg(msg,1)
          call cerrorMsg('-------------------------------',1)
          if( Bndryerr  .gt. 100 ) then
@@ -81,7 +82,7 @@ c         issue messages.
          if(Cn .ne. cnxx) then
             cTrack.cn = cnxx
             pos = cTrack.pos
-            call epnewComp
+            call epnewComp(cTrack)
          else
             pos = cTrack.pos
             cTrack.pos.x = cTrack.pos.x - EpsLeng*cTrack.w.x
@@ -91,7 +92,9 @@ c         issue messages.
          el = EpsLeng
          icon = 1
          jcon = 0
+         CrossMode = 0
       else
+         CrossMode = 0
 c          partial  container's boundary, if any, may be closer
          do j = 1, Det.cmp(Cn).NPContainer
 c((((((((((
@@ -102,6 +105,7 @@ c))))))))))))
             if(jcon  .eq. 0) then
                if(el2 .lt.  el) then
                   el = el2
+                  CrossMode = 2
                endif
             endif
          enddo
@@ -113,6 +117,7 @@ c           call epbndry2(Det.cmp(Cn).Contains(i),  tmpel, jcon)
 c))))))))))
             if(jcon .eq. 1 .and. tmpel .lt. el) then
                el = tmpel
+               CrossMode = 1
             endif
          enddo
          pos.x = cTrack.pos.x + el*cTrack.w.x
@@ -178,24 +183,3 @@ c
            endif
         endif
         end
-      subroutine epnewComp
-      implicit none
-#include "ZepTrackv.h"
-#include "Zcnfig.h"
-c         when a particle moves  to a new component
-c         the following must be done
-      Cn = cTrack.cn
-      MediaNo = Det.Cn2media(Cn)
-      Media(MediaNo).rhoc = Det.cmp(Cn).rhoc
-
-c       r.l                         cm   / X0;
-c            1/X0 = 1/(X0g/rho) = rho/X0g -->rho*rhoc/X0g
-      MaxPath =abs( Det.cmp(Cn).MaxPathL/Media(MediaNo).X0*
-     * Media(MediaNo).rhoc)
-
-c         Det.cmp(Cn).MaxPathL may be < 0; which means
-c        that the value is set by Epics and abs should be used.
-c         already dummy
-c      call ep2cosCond(Media(MediaNo).Aeff, Media(MediaNo).Zeff)
-      call ep2cosCond
-      end
