@@ -1612,14 +1612,24 @@ c              for small basic cross section case.
             endif
          else
             call ep2cosPtcl( cTrack.p )
+c            if(  k == kmuon .and. cTrack.p.charge == -1  .and.
+c     *           cTrack.p.fm.p(4) <= cTrack.p.mass*1.001) then
+c                        1.001 must be the same as in cinteMuon
+c                 for decay of stopping mu-, 
+c                 we must fix target for capture case; really captured
+c                 or decay  is determined in cinteMuon; 
+
+            if(  k == kmuon ) then
+c                 altough next is used only for negative stoppingmuons  
+c                 we call next for all muons so that epfixTarget
+c                 can be called by all muons.
+               call epgetCaprate( Media(MediaNo) ) ! equiv. to epgetXsec
+            endif
+
             call epfixTarget(ActiveMdl, Media(MediaNo))
-            call ep2cosCond2(Media(MediaNo).colA, Media(MediaNo).colZ,
-     *           Media(MediaNo).colXs)
-c//////////////
-c            if(show) then
-c               write(0,*)  ' inteNEP;proc=' , Move.proc
-c            endif
-c////////////////
+            call ep2cosCond2(Media(MediaNo).colA,
+     *           Media(MediaNo).colZ,  Media(MediaNo).colXs)
+
             call cinteNEP       ! cosmos eppp
             call eppushPtcl( cTrack )
          endif
@@ -2402,3 +2412,14 @@ c//////////
          write(0,*) ' struc =', struc
 
       end
+
+      subroutine epcurrent
+#include "ZepTrackp.h"
+#include "ZepTrackv.h"
+            write(*,*) ' now ground'
+            write(*,*) ' target A,Z=',Media(MediaNo).colA,
+     *         Media(MediaNo).colZ
+            write(*,*) ' code=',cTrack.p.code, ' chg=',
+     *                 cTrack.p.charge, ' sub=', cTrack.p.subcode,
+     *               ' Ek=',cTrack.p.fm.p(4)-cTrack.p.mass
+            end
